# 1 "read.mll"
 
  module Lexing =
    (*
      We override Lexing.engine in order to avoid creating a new position
      record each time a rule is matched.
      This reduces total parsing time by about 31%.
    *)
  struct
    include Lexing

    external c_engine : lex_tables -> int -> lexbuf -> int = "caml_lex_engine"

    let engine tbl state buf =
      let result = c_engine tbl state buf in
      (*
      if result >= 0 then begin
	buf.lex_start_p <- buf.lex_curr_p;
	buf.lex_curr_p <- {buf.lex_curr_p
			   with pos_cnum = buf.lex_abs_pos + buf.lex_curr_pos};
      end;
      *)
      result
  end

  open Printf
  open Lexing

  (* see description in common.mli *)
  type lexer_state = Lexer_state.t = {
    buf : Bi_outbuf.t;
    mutable lnum : int;
    mutable bol : int;
    mutable fname : string option;
  }

  let dec c =
    Char.code c - 48

  let hex c =
    match c with
	'0'..'9' -> int_of_char c - int_of_char '0'
      | 'a'..'f' -> int_of_char c - int_of_char 'a' + 10
      | 'A'..'F' -> int_of_char c - int_of_char 'A' + 10
      | _ -> assert false

  let custom_error descr v lexbuf =
    let offs = lexbuf.lex_abs_pos in
    let bol = v.bol in
    let pos1 = offs + lexbuf.lex_start_pos - bol in
    let pos2 = max pos1 (offs + lexbuf.lex_curr_pos - bol - 1) in
    let file_line =
      match v.fname with
	  None -> "Line"
	| Some s ->
	    sprintf "File %s, line" s
    in
    let bytes =
      if pos1 = pos2 then
	sprintf "byte %i" (pos1+1)
      else
	sprintf "bytes %i-%i" (pos1+1) (pos2+1)
    in
    let msg = sprintf "%s %i, %s:\n%s" file_line v.lnum bytes descr in
    json_error msg


  let lexer_error descr v lexbuf =
    custom_error 
      (sprintf "%s '%s'" descr (Lexing.lexeme lexbuf))
      v lexbuf

  let read_junk = ref (fun _ -> assert false)

  let long_error descr v lexbuf =
    let junk = Lexing.lexeme lexbuf in
    let extra_junk = !read_junk lexbuf in
    custom_error 
      (sprintf "%s '%s%s'" descr junk extra_junk)
      v lexbuf

  let min10 = min_int / 10 - (if min_int mod 10 = 0 then 0 else 1)
  let max10 = max_int / 10 + (if max_int mod 10 = 0 then 0 else 1)

  exception Int_overflow

  let extract_positive_int lexbuf =
    let start = lexbuf.lex_start_pos in
    let stop = lexbuf.lex_curr_pos in
    let s = lexbuf.lex_buffer in
    let n = ref 0 in
    for i = start to stop - 1 do
      if !n >= max10 then
	raise Int_overflow
      else
	n := 10 * !n + dec s.[i]
    done;
    if !n < 0 then
      raise Int_overflow
    else
      !n

  let make_positive_int v lexbuf =
    #ifdef INT
      try `Int (extract_positive_int lexbuf)
      with Int_overflow ->
    #endif
      #ifdef INTLIT
	`Intlit (lexeme lexbuf)
      #else
        lexer_error "Int overflow" v lexbuf
      #endif

  let extract_negative_int lexbuf =
    let start = lexbuf.lex_start_pos + 1 in
    let stop = lexbuf.lex_curr_pos in
    let s = lexbuf.lex_buffer in
    let n = ref 0 in
    for i = start to stop - 1 do
      if !n <= min10 then
	raise Int_overflow
      else
	n := 10 * !n - dec s.[i]
    done;
    if !n > 0 then
      raise Int_overflow
    else
      !n

  let make_negative_int v lexbuf =
    #ifdef INT
      try `Int (extract_negative_int lexbuf)
      with Int_overflow ->
    #endif
      #ifdef INTLIT
	`Intlit (lexeme lexbuf)
      #else
        lexer_error "Int overflow" v lexbuf
      #endif


  let set_file_name v fname =
    v.fname <- fname

  let newline v lexbuf =
    v.lnum <- v.lnum + 1;
    v.bol <- lexbuf.lex_abs_pos + lexbuf.lex_curr_pos

  let add_lexeme buf lexbuf =
    let len = lexbuf.lex_curr_pos - lexbuf.lex_start_pos in
    Bi_outbuf.add_substring buf lexbuf.lex_buffer lexbuf.lex_start_pos len

  let map_lexeme f lexbuf =
    let len = lexbuf.lex_curr_pos - lexbuf.lex_start_pos in
    f lexbuf.lex_buffer lexbuf.lex_start_pos len

  type variant_kind = [ `Edgy_bracket | `Square_bracket | `Double_quote ]
  type tuple_kind = [ `Parenthesis | `Square_bracket ]

# 161 "read.ml"
let __ocaml_lex_tables = {
  Lexing.lex_base = 
   "\000\000\236\255\237\255\003\000\239\255\016\000\242\255\243\255\
    \244\255\245\255\000\000\031\000\249\255\085\000\001\000\000\000\
    \000\000\001\000\000\000\001\000\002\000\255\255\000\000\000\000\
    \003\000\254\255\001\000\004\000\253\255\011\000\252\255\003\000\
    \001\000\003\000\002\000\003\000\000\000\251\255\021\000\097\000\
    \010\000\022\000\020\000\016\000\022\000\012\000\008\000\250\255\
    \119\000\129\000\139\000\161\000\171\000\181\000\193\000\209\000\
    \240\255\011\000\038\000\252\255\065\000\254\255\255\255\110\000\
    \252\255\163\000\254\255\255\255\234\000\247\255\248\255\048\001\
    \250\255\251\255\252\255\253\255\254\255\255\255\071\001\126\001\
    \149\001\249\255\039\000\253\255\254\255\038\000\187\001\210\001\
    \248\001\015\002\255\255\220\000\253\255\255\255\245\000\039\002\
    \109\002\014\001\088\002\164\002\187\002\225\002\013\000\252\255\
    \253\255\254\255\255\255\014\000\253\255\254\255\255\255\030\000\
    \253\255\254\255\255\255\015\000\253\255\254\255\255\255\017\001\
    \251\255\252\255\253\255\254\255\255\255\019\000\252\255\253\255\
    \254\255\015\000\255\255\016\000\255\255\008\001\005\000\253\255\
    \023\000\254\255\020\000\255\255\046\000\253\255\254\255\042\000\
    \052\000\053\000\255\255\053\000\048\000\091\000\092\000\255\255\
    \185\000\252\255\253\255\104\000\089\000\088\000\106\000\255\255\
    \131\000\136\000\151\000\254\255\053\002\251\255\252\255\253\255\
    \103\001\255\255\248\002\254\255\006\003\030\003\252\255\253\255\
    \254\255\255\255\040\003\050\003\074\003\252\255\253\255\254\255\
    \255\255\061\003\084\003\108\003\249\255\250\255\251\255\234\000\
    \120\003\142\003\143\000\181\000\015\000\255\255\180\000\178\000\
    \174\000\180\000\172\000\168\000\254\255\180\000\189\000\187\000\
    \183\000\192\000\182\000\178\000\253\255\157\003\095\003\174\003\
    \196\003\206\003\216\003\228\003\239\003\060\000\253\255\254\255\
    \255\255\012\004\252\255\253\255\087\004\255\255\145\004\252\255\
    \253\255\221\004\255\255\209\000\253\255\254\255\255\255\222\000\
    \253\255\254\255\255\255\002\000\255\255\018\001\252\255\253\255\
    \254\255\255\255\012\001\253\255\254\255\255\255\000\000\255\255\
    \003\000\254\255\255\255\025\001\252\255\253\255\254\255\255\255\
    \120\001\251\255\252\255\253\255\254\255\255\255\186\000\253\255\
    \254\255\255\255\187\000\253\255\254\255\255\255\180\000\255\255\
    \144\001\252\255\253\255\254\255\255\255\015\001\253\255\254\255\
    \255\255\038\001\252\255\253\255\254\255\255\255\027\001\253\255\
    \254\255\255\255\034\001\253\255\254\255\255\255\229\000\253\255\
    \254\255\255\255\221\000\253\255\254\255\255\255\079\005\237\255\
    \238\255\006\000\240\255\021\001\243\255\244\255\245\255\246\255\
    \043\001\002\004\249\255\045\005\196\000\218\000\200\000\230\000\
    \214\000\213\000\237\000\255\255\231\000\225\000\240\000\254\255\
    \234\000\235\000\253\255\012\001\252\255\245\000\244\000\253\000\
    \004\001\014\001\010\001\251\255\022\001\031\001\029\001\025\001\
    \037\001\027\001\041\001\250\255\110\005\012\004\123\005\155\005\
    \165\005\177\005\187\005\197\005\241\255\197\001\199\001\253\255\
    \255\255\003\002\222\005\209\005\077\002\239\005\053\006\076\006\
    \114\006\150\001\252\255\253\255\254\255\255\255\152\006\252\255\
    \253\255\227\006\255\255\165\000\166\000\167\000\255\255\184\000\
    \189\000\190\000\210\000\211\000\230\000\231\000\232\000\016\001\
    \026\001\036\001\039\001\050\001\074\001\075\001\076\001\077\001\
    \078\001\079\001\088\001\096\001\097\001\099\001\100\001\118\001\
    \119\001\121\001\123\001\124\001\000\000";
  Lexing.lex_backtrk = 
   "\255\255\255\255\255\255\017\000\255\255\019\000\255\255\255\255\
    \255\255\255\255\007\000\007\000\255\255\019\000\019\000\019\000\
    \019\000\019\000\019\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\008\000\008\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\009\000\255\255\009\000\255\255\009\000\255\255\
    \255\255\014\000\255\255\255\255\002\000\255\255\255\255\255\255\
    \255\255\002\000\255\255\255\255\255\255\255\255\255\255\007\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\001\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\001\000\001\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\003\000\255\255\001\000\255\255\004\000\003\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\001\000\
    \255\255\255\255\255\255\001\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\002\000\002\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \003\000\255\255\000\000\255\255\001\000\255\255\255\255\255\255\
    \255\255\255\255\000\000\002\000\255\255\255\255\255\255\255\255\
    \255\255\000\000\002\000\255\255\255\255\255\255\255\255\003\000\
    \003\000\005\000\005\000\005\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\003\000\
    \255\255\003\000\255\255\003\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\001\000\255\255\255\255\255\255\
    \255\255\001\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\001\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\001\000\255\255\
    \002\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\001\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\016\000\255\255\018\000\255\255\255\255\255\255\255\255\
    \007\000\007\000\255\255\018\000\018\000\018\000\018\000\018\000\
    \018\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\008\000\255\255\
    \008\000\255\255\008\000\255\255\255\255\013\000\255\255\255\255\
    \255\255\001\000\001\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\001\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255";
  Lexing.lex_default = 
   "\001\000\000\000\000\000\255\255\000\000\255\255\000\000\000\000\
    \000\000\000\000\255\255\255\255\000\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\255\255\
    \255\255\000\000\255\255\255\255\000\000\255\255\000\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\000\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\057\000\060\000\000\000\060\000\000\000\000\000\065\000\
    \000\000\065\000\000\000\000\000\070\000\000\000\000\000\255\255\
    \000\000\000\000\000\000\000\000\000\000\000\000\255\255\255\255\
    \255\255\000\000\084\000\000\000\000\000\255\255\255\255\255\255\
    \255\255\255\255\000\000\094\000\000\000\000\000\097\000\255\255\
    \255\255\097\000\255\255\255\255\255\255\255\255\104\000\000\000\
    \000\000\000\000\000\000\109\000\000\000\000\000\000\000\113\000\
    \000\000\000\000\000\000\117\000\000\000\000\000\000\000\121\000\
    \000\000\000\000\000\000\000\000\000\000\126\000\000\000\000\000\
    \000\000\255\255\000\000\255\255\000\000\255\255\255\255\000\000\
    \255\255\000\000\138\000\000\000\142\000\000\000\000\000\255\255\
    \255\255\255\255\000\000\255\255\255\255\255\255\255\255\000\000\
    \154\000\000\000\000\000\255\255\255\255\255\255\255\255\000\000\
    \255\255\255\255\255\255\000\000\166\000\000\000\000\000\000\000\
    \255\255\000\000\255\255\000\000\255\255\175\000\000\000\000\000\
    \000\000\000\000\255\255\255\255\182\000\000\000\000\000\000\000\
    \000\000\255\255\255\255\189\000\000\000\000\000\000\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\000\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\000\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\223\000\000\000\000\000\
    \000\000\227\000\000\000\000\000\255\255\000\000\232\000\000\000\
    \000\000\255\255\000\000\237\000\000\000\000\000\000\000\241\000\
    \000\000\000\000\000\000\255\255\000\000\247\000\000\000\000\000\
    \000\000\000\000\252\000\000\000\000\000\000\000\255\255\000\000\
    \255\255\000\000\000\000\005\001\000\000\000\000\000\000\000\000\
    \010\001\000\000\000\000\000\000\000\000\000\000\016\001\000\000\
    \000\000\000\000\020\001\000\000\000\000\000\000\255\255\000\000\
    \026\001\000\000\000\000\000\000\000\000\031\001\000\000\000\000\
    \000\000\035\001\000\000\000\000\000\000\000\000\040\001\000\000\
    \000\000\000\000\044\001\000\000\000\000\000\000\048\001\000\000\
    \000\000\000\000\052\001\000\000\000\000\000\000\055\001\000\000\
    \000\000\255\255\000\000\255\255\000\000\000\000\000\000\000\000\
    \255\255\255\255\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\000\000\255\255\255\255\255\255\000\000\
    \255\255\255\255\000\000\255\255\000\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\000\000\109\001\113\001\000\000\
    \000\000\116\001\255\255\255\255\116\001\255\255\255\255\255\255\
    \255\255\123\001\000\000\000\000\000\000\000\000\128\001\000\000\
    \000\000\255\255\000\000\132\001\133\001\135\001\000\000\136\001\
    \137\001\138\001\139\001\140\001\141\001\142\001\143\001\144\001\
    \145\001\146\001\147\001\148\001\149\001\150\001\151\001\152\001\
    \153\001\154\001\155\001\156\001\157\001\158\001\159\001\160\001\
    \161\001\162\001\163\001\164\001\134\001";
  Lexing.lex_trans = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\003\000\004\000\000\000\003\000\003\000\134\000\057\001\
    \003\000\000\000\134\000\057\001\000\000\255\255\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\127\000\139\000\000\000\
    \003\000\000\000\012\000\003\000\000\000\134\000\057\001\000\000\
    \007\000\255\000\000\000\000\000\002\001\013\000\049\000\005\000\
    \010\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\056\000\118\000\006\000\129\000\130\000\057\000\
    \000\000\137\000\000\000\049\000\000\000\048\000\138\000\106\000\
    \062\000\014\000\110\000\105\000\000\000\049\000\015\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\030\000\048\000\008\000\114\000\197\000\224\000\244\000\
    \001\001\029\000\022\000\255\255\048\000\048\000\017\000\021\000\
    \025\000\032\000\033\000\035\000\023\000\027\000\016\000\031\000\
    \028\000\034\000\019\000\024\000\018\000\026\000\020\000\036\000\
    \041\000\037\000\048\000\009\000\042\000\043\000\044\000\045\000\
    \046\000\047\000\061\000\085\000\048\000\038\000\039\000\039\000\
    \039\000\039\000\039\000\039\000\039\000\039\000\039\000\049\000\
    \067\000\039\000\039\000\039\000\039\000\039\000\039\000\039\000\
    \039\000\039\000\039\000\086\000\143\000\255\255\040\000\144\000\
    \145\000\146\000\055\000\148\000\055\000\149\000\048\000\054\000\
    \054\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\050\000\255\255\048\000\150\000\
    \151\000\160\000\066\000\157\000\053\000\158\000\053\000\159\000\
    \051\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\161\000\
    \051\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\162\000\163\000\198\000\093\000\255\255\
    \002\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\255\255\077\000\103\000\108\000\116\000\
    \132\000\134\000\135\000\128\000\139\000\134\000\196\000\093\000\
    \214\000\077\000\199\000\200\000\201\000\202\000\112\000\155\000\
    \203\000\204\000\206\000\207\000\208\000\209\000\059\000\083\000\
    \134\000\210\000\211\000\212\000\238\000\156\000\141\000\213\000\
    \093\000\023\001\085\001\123\000\253\000\017\001\021\001\136\000\
    \095\000\242\000\053\001\083\001\222\000\080\001\249\000\108\001\
    \049\001\255\255\006\001\041\001\109\001\007\001\077\000\076\001\
    \073\001\032\001\074\001\045\001\076\000\124\000\037\001\213\000\
    \075\000\098\000\075\001\077\001\078\001\079\001\081\001\082\001\
    \074\000\101\001\084\001\086\001\073\000\087\001\072\000\071\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\078\000\098\000\088\001\122\000\089\001\064\000\248\000\
    \100\001\078\000\078\000\078\000\078\000\078\000\078\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \079\000\036\001\090\001\091\001\093\001\094\001\095\001\096\001\
    \079\000\079\000\079\000\079\000\079\000\079\000\097\001\098\001\
    \100\001\078\000\078\000\078\000\078\000\078\000\078\000\171\000\
    \172\000\172\000\172\000\172\000\172\000\172\000\172\000\172\000\
    \172\000\012\001\099\001\255\255\013\001\255\255\134\001\134\001\
    \079\000\079\000\079\000\079\000\079\000\079\000\080\000\080\000\
    \080\000\080\000\080\000\080\000\080\000\080\000\080\000\080\000\
    \134\001\153\000\015\001\019\001\028\001\134\001\134\001\080\000\
    \080\000\080\000\080\000\080\000\080\000\081\000\081\000\081\000\
    \081\000\081\000\081\000\081\000\081\000\081\000\081\000\255\255\
    \125\001\236\000\134\001\134\001\124\001\011\001\081\000\081\000\
    \081\000\081\000\081\000\081\000\092\000\051\001\240\000\080\000\
    \080\000\080\000\080\000\080\000\080\000\047\001\134\001\134\001\
    \134\001\112\001\069\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\087\000\255\255\081\000\081\000\
    \081\000\081\000\081\000\081\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\088\000\088\000\088\000\088\000\088\000\088\000\
    \088\000\088\000\088\000\088\000\251\000\027\001\255\255\030\001\
    \134\001\120\000\246\000\088\000\088\000\088\000\088\000\088\000\
    \088\000\004\001\134\001\039\001\087\000\087\000\087\000\087\000\
    \087\000\087\000\043\001\114\001\134\001\112\001\034\001\134\001\
    \089\000\089\000\089\000\089\000\089\000\089\000\089\000\089\000\
    \089\000\089\000\134\001\088\000\088\000\088\000\088\000\088\000\
    \088\000\089\000\089\000\089\000\089\000\089\000\089\000\090\000\
    \090\000\090\000\090\000\090\000\090\000\090\000\090\000\090\000\
    \090\000\097\000\134\001\134\001\134\001\134\001\134\001\134\001\
    \090\000\090\000\090\000\090\000\090\000\090\000\097\000\167\000\
    \134\001\089\000\089\000\089\000\089\000\089\000\089\000\117\001\
    \134\001\134\001\168\000\134\001\134\001\169\000\170\000\170\000\
    \170\000\170\000\170\000\170\000\170\000\170\000\170\000\112\001\
    \090\000\090\000\090\000\090\000\090\000\090\000\134\001\134\001\
    \009\001\134\001\097\000\134\001\134\001\000\000\000\000\000\000\
    \000\000\000\000\000\000\097\000\000\000\000\000\000\000\097\000\
    \000\000\097\000\000\000\000\000\000\000\097\000\000\000\000\000\
    \025\001\000\000\000\000\000\000\000\000\097\000\122\001\000\000\
    \000\000\097\000\000\000\097\000\096\000\099\000\099\000\099\000\
    \099\000\099\000\099\000\099\000\099\000\099\000\099\000\000\000\
    \000\000\117\001\000\000\000\000\000\000\000\000\099\000\099\000\
    \099\000\099\000\099\000\099\000\097\000\000\000\000\000\000\000\
    \000\000\000\000\097\000\000\000\000\000\000\000\097\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\255\255\097\000\111\001\
    \000\000\000\000\097\000\000\000\097\000\096\000\099\000\099\000\
    \099\000\099\000\099\000\099\000\100\000\100\000\100\000\100\000\
    \100\000\100\000\100\000\100\000\100\000\100\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\100\000\100\000\100\000\
    \100\000\100\000\100\000\101\000\101\000\101\000\101\000\101\000\
    \101\000\101\000\101\000\101\000\101\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\101\000\101\000\101\000\101\000\
    \101\000\101\000\000\000\255\255\000\000\100\000\100\000\100\000\
    \100\000\100\000\100\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\097\000\097\000\097\000\097\000\097\000\097\000\097\000\
    \097\000\097\000\097\000\000\000\101\000\101\000\101\000\101\000\
    \101\000\101\000\097\000\097\000\097\000\097\000\097\000\097\000\
    \170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\
    \170\000\170\000\000\000\000\000\000\000\165\000\172\000\172\000\
    \172\000\172\000\172\000\172\000\172\000\172\000\172\000\172\000\
    \176\000\000\000\097\000\097\000\097\000\097\000\097\000\097\000\
    \000\000\000\000\000\000\179\000\000\000\255\255\177\000\178\000\
    \178\000\178\000\178\000\178\000\178\000\178\000\178\000\178\000\
    \178\000\178\000\178\000\178\000\178\000\178\000\178\000\178\000\
    \178\000\178\000\177\000\178\000\178\000\178\000\178\000\178\000\
    \178\000\178\000\178\000\178\000\183\000\185\000\185\000\185\000\
    \185\000\185\000\185\000\185\000\185\000\185\000\185\000\186\000\
    \000\000\000\000\184\000\185\000\185\000\185\000\185\000\185\000\
    \185\000\185\000\185\000\185\000\184\000\185\000\185\000\185\000\
    \185\000\185\000\185\000\185\000\185\000\185\000\190\000\215\000\
    \215\000\215\000\215\000\215\000\215\000\215\000\215\000\215\000\
    \215\000\193\000\000\000\000\000\191\000\192\000\192\000\192\000\
    \192\000\192\000\192\000\192\000\192\000\192\000\214\000\000\000\
    \192\000\192\000\192\000\192\000\192\000\192\000\192\000\192\000\
    \192\000\192\000\000\000\000\000\000\000\194\000\000\000\000\000\
    \000\000\000\000\195\000\000\000\000\000\213\000\191\000\192\000\
    \192\000\192\000\192\000\192\000\192\000\192\000\192\000\192\000\
    \220\000\000\000\220\000\000\000\000\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\219\000\219\000\205\000\
    \000\000\000\000\000\000\000\000\000\000\213\000\215\000\215\000\
    \215\000\215\000\215\000\215\000\215\000\215\000\215\000\215\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\218\000\
    \000\000\218\000\000\000\216\000\217\000\217\000\217\000\217\000\
    \217\000\217\000\217\000\217\000\217\000\217\000\217\000\217\000\
    \217\000\217\000\217\000\217\000\217\000\217\000\217\000\217\000\
    \217\000\217\000\217\000\217\000\217\000\217\000\217\000\217\000\
    \217\000\217\000\000\000\216\000\219\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\219\000\174\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\219\000\219\000\219\000\
    \219\000\000\000\000\000\000\000\000\000\000\000\229\000\000\000\
    \101\001\000\000\065\001\065\001\065\001\065\001\065\001\065\001\
    \065\001\065\001\065\001\065\001\102\001\102\001\102\001\102\001\
    \102\001\102\001\102\001\102\001\102\001\102\001\000\000\100\001\
    \000\000\000\000\181\000\000\000\000\000\228\000\228\000\228\000\
    \228\000\228\000\228\000\228\000\228\000\228\000\228\000\228\000\
    \228\000\228\000\228\000\228\000\228\000\228\000\228\000\228\000\
    \228\000\228\000\228\000\228\000\228\000\228\000\228\000\100\001\
    \000\000\000\000\000\000\228\000\188\000\228\000\228\000\228\000\
    \228\000\228\000\228\000\228\000\228\000\228\000\228\000\228\000\
    \228\000\228\000\228\000\228\000\228\000\228\000\228\000\228\000\
    \228\000\228\000\228\000\228\000\228\000\228\000\228\000\228\000\
    \228\000\228\000\228\000\228\000\228\000\228\000\228\000\228\000\
    \228\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \228\000\228\000\228\000\228\000\228\000\228\000\228\000\228\000\
    \228\000\228\000\228\000\228\000\228\000\228\000\228\000\228\000\
    \228\000\228\000\228\000\228\000\228\000\228\000\228\000\228\000\
    \228\000\228\000\000\000\234\000\000\000\000\000\228\000\000\000\
    \228\000\228\000\228\000\228\000\228\000\228\000\228\000\228\000\
    \228\000\228\000\228\000\228\000\228\000\228\000\228\000\228\000\
    \228\000\228\000\228\000\228\000\228\000\228\000\228\000\228\000\
    \228\000\228\000\233\000\233\000\233\000\233\000\233\000\233\000\
    \233\000\233\000\233\000\233\000\233\000\233\000\233\000\233\000\
    \233\000\233\000\233\000\233\000\233\000\233\000\233\000\233\000\
    \233\000\233\000\233\000\233\000\000\000\000\000\000\000\000\000\
    \233\000\000\000\233\000\233\000\233\000\233\000\233\000\233\000\
    \233\000\233\000\233\000\233\000\233\000\233\000\233\000\233\000\
    \233\000\233\000\233\000\233\000\233\000\233\000\233\000\233\000\
    \233\000\233\000\233\000\233\000\226\000\233\000\233\000\233\000\
    \233\000\233\000\233\000\233\000\233\000\233\000\233\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\233\000\233\000\
    \233\000\233\000\233\000\233\000\233\000\233\000\233\000\233\000\
    \233\000\233\000\233\000\233\000\233\000\233\000\233\000\233\000\
    \233\000\233\000\233\000\233\000\233\000\233\000\233\000\233\000\
    \000\000\000\000\000\000\000\000\233\000\000\000\233\000\233\000\
    \233\000\233\000\233\000\233\000\233\000\233\000\233\000\233\000\
    \233\000\233\000\233\000\233\000\233\000\233\000\233\000\233\000\
    \233\000\233\000\233\000\233\000\233\000\233\000\233\000\233\000\
    \057\001\058\001\000\000\000\000\057\001\064\001\065\001\065\001\
    \065\001\065\001\065\001\065\001\065\001\065\001\065\001\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\057\001\
    \000\000\066\001\000\000\000\000\000\000\000\000\092\001\061\001\
    \000\000\000\000\000\000\000\000\067\001\000\000\059\001\064\001\
    \065\001\065\001\065\001\065\001\065\001\065\001\065\001\065\001\
    \065\001\000\000\000\000\060\001\000\000\000\000\000\000\000\000\
    \000\000\231\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \068\001\107\001\000\000\107\001\000\000\069\001\106\001\106\001\
    \106\001\106\001\106\001\106\001\106\001\106\001\106\001\106\001\
    \000\000\000\000\062\001\102\001\102\001\102\001\102\001\102\001\
    \102\001\102\001\102\001\102\001\102\001\071\001\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\070\001\000\000\000\000\
    \103\001\000\000\000\000\072\001\000\000\000\000\105\001\000\000\
    \105\001\000\000\063\001\104\001\104\001\104\001\104\001\104\001\
    \104\001\104\001\104\001\104\001\104\001\104\001\104\001\104\001\
    \104\001\104\001\104\001\104\001\104\001\104\001\104\001\000\000\
    \103\001\104\001\104\001\104\001\104\001\104\001\104\001\104\001\
    \104\001\104\001\104\001\106\001\106\001\106\001\106\001\106\001\
    \106\001\106\001\106\001\106\001\106\001\106\001\106\001\106\001\
    \106\001\106\001\106\001\106\001\106\001\106\001\106\001\000\000\
    \116\001\118\001\118\001\118\001\118\001\118\001\118\001\118\001\
    \118\001\118\001\118\001\000\000\000\000\116\001\000\000\000\000\
    \000\000\116\001\118\001\118\001\118\001\118\001\118\001\118\001\
    \000\000\000\000\000\000\000\000\000\000\000\000\116\001\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\118\001\118\001\118\001\118\001\118\001\118\001\
    \000\000\000\000\116\001\000\000\000\000\000\000\000\000\000\000\
    \116\001\000\000\000\000\000\000\116\001\000\000\000\000\000\000\
    \000\000\000\000\000\000\116\001\116\001\000\000\000\000\056\001\
    \116\001\116\001\116\001\115\001\000\000\116\001\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\116\001\000\000\000\000\
    \000\000\116\001\000\000\116\001\115\001\119\001\119\001\119\001\
    \119\001\119\001\119\001\119\001\119\001\119\001\119\001\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\119\001\119\001\
    \119\001\119\001\119\001\119\001\120\001\120\001\120\001\120\001\
    \120\001\120\001\120\001\120\001\120\001\120\001\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\120\001\120\001\120\001\
    \120\001\120\001\120\001\000\000\000\000\000\000\119\001\119\001\
    \119\001\119\001\119\001\119\001\000\000\000\000\000\000\000\000\
    \000\000\000\000\116\001\116\001\116\001\116\001\116\001\116\001\
    \116\001\116\001\116\001\116\001\000\000\120\001\120\001\120\001\
    \120\001\120\001\120\001\116\001\116\001\116\001\116\001\116\001\
    \116\001\000\000\130\001\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\116\001\116\001\116\001\116\001\116\001\
    \116\001\129\001\129\001\129\001\129\001\129\001\129\001\129\001\
    \129\001\129\001\129\001\129\001\129\001\129\001\129\001\129\001\
    \129\001\129\001\129\001\129\001\129\001\129\001\129\001\129\001\
    \129\001\129\001\129\001\000\000\000\000\000\000\000\000\129\001\
    \000\000\129\001\129\001\129\001\129\001\129\001\129\001\129\001\
    \129\001\129\001\129\001\129\001\129\001\129\001\129\001\129\001\
    \129\001\129\001\129\001\129\001\129\001\129\001\129\001\129\001\
    \129\001\129\001\129\001\129\001\129\001\129\001\129\001\129\001\
    \129\001\129\001\129\001\129\001\129\001\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\129\001\129\001\129\001\129\001\
    \129\001\129\001\129\001\129\001\129\001\129\001\129\001\129\001\
    \129\001\129\001\129\001\129\001\129\001\129\001\129\001\129\001\
    \129\001\129\001\129\001\129\001\129\001\129\001\000\000\000\000\
    \000\000\000\000\129\001\000\000\129\001\129\001\129\001\129\001\
    \129\001\129\001\129\001\129\001\129\001\129\001\129\001\129\001\
    \129\001\129\001\129\001\129\001\129\001\129\001\129\001\129\001\
    \129\001\129\001\129\001\129\001\129\001\129\001\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \127\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000";
  Lexing.lex_check = 
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\255\255\003\000\000\000\134\000\057\001\
    \003\000\255\255\134\000\057\001\255\255\057\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\125\000\138\000\255\255\
    \000\000\255\255\000\000\003\000\255\255\134\000\057\001\255\255\
    \000\000\254\000\255\255\255\255\000\001\000\000\010\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\005\000\115\000\000\000\125\000\129\000\005\000\
    \255\255\136\000\255\255\038\000\255\255\010\000\136\000\102\000\
    \058\000\000\000\107\000\102\000\255\255\011\000\000\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\029\000\038\000\000\000\111\000\196\000\221\000\243\000\
    \000\001\015\000\017\000\060\000\011\000\010\000\000\000\020\000\
    \024\000\031\000\032\000\034\000\022\000\026\000\000\000\014\000\
    \027\000\033\000\018\000\023\000\000\000\016\000\019\000\035\000\
    \040\000\036\000\038\000\000\000\041\000\042\000\043\000\044\000\
    \045\000\046\000\058\000\082\000\011\000\013\000\013\000\013\000\
    \013\000\013\000\013\000\013\000\013\000\013\000\013\000\039\000\
    \063\000\039\000\039\000\039\000\039\000\039\000\039\000\039\000\
    \039\000\039\000\039\000\085\000\140\000\060\000\013\000\143\000\
    \144\000\145\000\048\000\147\000\048\000\148\000\039\000\048\000\
    \048\000\048\000\048\000\048\000\048\000\048\000\048\000\048\000\
    \048\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\049\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\050\000\050\000\050\000\050\000\065\000\039\000\149\000\
    \150\000\155\000\063\000\156\000\051\000\157\000\051\000\158\000\
    \050\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \051\000\051\000\051\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\052\000\052\000\053\000\053\000\053\000\
    \053\000\053\000\053\000\053\000\053\000\053\000\053\000\160\000\
    \050\000\054\000\054\000\054\000\054\000\054\000\054\000\054\000\
    \054\000\054\000\054\000\161\000\162\000\194\000\091\000\065\000\
    \000\000\055\000\055\000\055\000\055\000\055\000\055\000\055\000\
    \055\000\055\000\055\000\057\000\068\000\102\000\107\000\115\000\
    \131\000\133\000\133\000\125\000\138\000\133\000\195\000\094\000\
    \191\000\068\000\198\000\199\000\200\000\201\000\111\000\152\000\
    \202\000\203\000\205\000\206\000\207\000\208\000\058\000\082\000\
    \133\000\209\000\210\000\211\000\235\000\152\000\140\000\191\000\
    \097\000\022\001\068\001\119\000\250\000\014\001\018\001\133\000\
    \091\000\239\000\050\001\069\001\221\000\070\001\245\000\059\001\
    \046\001\060\000\003\001\038\001\059\001\003\001\068\000\071\001\
    \072\001\029\001\073\001\042\001\068\000\119\000\033\001\191\000\
    \068\000\094\000\074\001\076\001\077\001\078\001\080\001\081\001\
    \068\000\064\001\083\001\085\001\068\000\086\001\068\000\068\000\
    \071\000\071\000\071\000\071\000\071\000\071\000\071\000\071\000\
    \071\000\071\000\097\000\087\001\119\000\088\001\063\000\245\000\
    \064\001\071\000\071\000\071\000\071\000\071\000\071\000\078\000\
    \078\000\078\000\078\000\078\000\078\000\078\000\078\000\078\000\
    \078\000\033\001\089\001\090\001\092\001\093\001\094\001\095\001\
    \078\000\078\000\078\000\078\000\078\000\078\000\096\001\097\001\
    \064\001\071\000\071\000\071\000\071\000\071\000\071\000\168\000\
    \168\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
    \168\000\008\001\098\001\065\000\008\001\131\001\132\001\133\001\
    \078\000\078\000\078\000\078\000\078\000\078\000\079\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\079\000\079\000\079\000\
    \135\001\152\000\014\001\018\001\024\001\136\001\137\001\079\000\
    \079\000\079\000\079\000\079\000\079\000\080\000\080\000\080\000\
    \080\000\080\000\080\000\080\000\080\000\080\000\080\000\109\001\
    \121\001\235\000\138\001\139\001\121\001\008\001\080\000\080\000\
    \080\000\080\000\080\000\080\000\091\000\050\001\239\000\079\000\
    \079\000\079\000\079\000\079\000\079\000\046\001\140\001\141\001\
    \142\001\110\001\068\000\086\000\086\000\086\000\086\000\086\000\
    \086\000\086\000\086\000\086\000\086\000\094\000\080\000\080\000\
    \080\000\080\000\080\000\080\000\086\000\086\000\086\000\086\000\
    \086\000\086\000\087\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\087\000\087\000\087\000\250\000\024\001\097\000\029\001\
    \143\001\119\000\245\000\087\000\087\000\087\000\087\000\087\000\
    \087\000\003\001\144\001\038\001\086\000\086\000\086\000\086\000\
    \086\000\086\000\042\001\110\001\145\001\113\001\033\001\146\001\
    \088\000\088\000\088\000\088\000\088\000\088\000\088\000\088\000\
    \088\000\088\000\147\001\087\000\087\000\087\000\087\000\087\000\
    \087\000\088\000\088\000\088\000\088\000\088\000\088\000\089\000\
    \089\000\089\000\089\000\089\000\089\000\089\000\089\000\089\000\
    \089\000\095\000\148\001\149\001\150\001\151\001\152\001\153\001\
    \089\000\089\000\089\000\089\000\089\000\089\000\095\000\164\000\
    \154\001\088\000\088\000\088\000\088\000\088\000\088\000\113\001\
    \155\001\156\001\164\000\157\001\158\001\164\000\164\000\164\000\
    \164\000\164\000\164\000\164\000\164\000\164\000\164\000\116\001\
    \089\000\089\000\089\000\089\000\089\000\089\000\159\001\160\001\
    \008\001\161\001\098\000\162\001\163\001\255\255\255\255\255\255\
    \255\255\255\255\255\255\095\000\255\255\255\255\255\255\098\000\
    \255\255\095\000\255\255\255\255\255\255\095\000\255\255\255\255\
    \024\001\255\255\255\255\255\255\255\255\095\000\121\001\255\255\
    \255\255\095\000\255\255\095\000\095\000\096\000\096\000\096\000\
    \096\000\096\000\096\000\096\000\096\000\096\000\096\000\255\255\
    \255\255\116\001\255\255\255\255\255\255\255\255\096\000\096\000\
    \096\000\096\000\096\000\096\000\098\000\255\255\255\255\255\255\
    \255\255\255\255\098\000\255\255\255\255\255\255\098\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\109\001\098\000\110\001\
    \255\255\255\255\098\000\255\255\098\000\098\000\096\000\096\000\
    \096\000\096\000\096\000\096\000\099\000\099\000\099\000\099\000\
    \099\000\099\000\099\000\099\000\099\000\099\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\099\000\099\000\099\000\
    \099\000\099\000\099\000\100\000\100\000\100\000\100\000\100\000\
    \100\000\100\000\100\000\100\000\100\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\100\000\100\000\100\000\100\000\
    \100\000\100\000\255\255\113\001\255\255\099\000\099\000\099\000\
    \099\000\099\000\099\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\101\000\101\000\101\000\101\000\101\000\101\000\101\000\
    \101\000\101\000\101\000\255\255\100\000\100\000\100\000\100\000\
    \100\000\100\000\101\000\101\000\101\000\101\000\101\000\101\000\
    \170\000\170\000\170\000\170\000\170\000\170\000\170\000\170\000\
    \170\000\170\000\255\255\255\255\255\255\164\000\172\000\172\000\
    \172\000\172\000\172\000\172\000\172\000\172\000\172\000\172\000\
    \173\000\255\255\101\000\101\000\101\000\101\000\101\000\101\000\
    \255\255\255\255\255\255\173\000\255\255\116\001\173\000\173\000\
    \173\000\173\000\173\000\173\000\173\000\173\000\173\000\173\000\
    \178\000\178\000\178\000\178\000\178\000\178\000\178\000\178\000\
    \178\000\178\000\179\000\179\000\179\000\179\000\179\000\179\000\
    \179\000\179\000\179\000\179\000\180\000\185\000\185\000\185\000\
    \185\000\185\000\185\000\185\000\185\000\185\000\185\000\180\000\
    \255\255\255\255\180\000\180\000\180\000\180\000\180\000\180\000\
    \180\000\180\000\180\000\180\000\186\000\186\000\186\000\186\000\
    \186\000\186\000\186\000\186\000\186\000\186\000\187\000\214\000\
    \214\000\214\000\214\000\214\000\214\000\214\000\214\000\214\000\
    \214\000\187\000\255\255\255\255\187\000\187\000\187\000\187\000\
    \187\000\187\000\187\000\187\000\187\000\187\000\192\000\255\255\
    \192\000\192\000\192\000\192\000\192\000\192\000\192\000\192\000\
    \192\000\192\000\255\255\255\255\255\255\187\000\255\255\255\255\
    \255\255\255\255\187\000\255\255\255\255\192\000\193\000\193\000\
    \193\000\193\000\193\000\193\000\193\000\193\000\193\000\193\000\
    \213\000\255\255\213\000\255\255\255\255\213\000\213\000\213\000\
    \213\000\213\000\213\000\213\000\213\000\213\000\213\000\193\000\
    \255\255\255\255\255\255\255\255\255\255\192\000\215\000\215\000\
    \215\000\215\000\215\000\215\000\215\000\215\000\215\000\215\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\216\000\
    \255\255\216\000\255\255\215\000\216\000\216\000\216\000\216\000\
    \216\000\216\000\216\000\216\000\216\000\216\000\217\000\217\000\
    \217\000\217\000\217\000\217\000\217\000\217\000\217\000\217\000\
    \218\000\218\000\218\000\218\000\218\000\218\000\218\000\218\000\
    \218\000\218\000\255\255\215\000\219\000\219\000\219\000\219\000\
    \219\000\219\000\219\000\219\000\219\000\219\000\173\000\220\000\
    \220\000\220\000\220\000\220\000\220\000\220\000\220\000\220\000\
    \220\000\255\255\255\255\255\255\255\255\255\255\225\000\255\255\
    \065\001\255\255\065\001\065\001\065\001\065\001\065\001\065\001\
    \065\001\065\001\065\001\065\001\101\001\101\001\101\001\101\001\
    \101\001\101\001\101\001\101\001\101\001\101\001\255\255\065\001\
    \255\255\255\255\180\000\255\255\255\255\225\000\225\000\225\000\
    \225\000\225\000\225\000\225\000\225\000\225\000\225\000\225\000\
    \225\000\225\000\225\000\225\000\225\000\225\000\225\000\225\000\
    \225\000\225\000\225\000\225\000\225\000\225\000\225\000\065\001\
    \255\255\255\255\255\255\225\000\187\000\225\000\225\000\225\000\
    \225\000\225\000\225\000\225\000\225\000\225\000\225\000\225\000\
    \225\000\225\000\225\000\225\000\225\000\225\000\225\000\225\000\
    \225\000\225\000\225\000\225\000\225\000\225\000\225\000\228\000\
    \228\000\228\000\228\000\228\000\228\000\228\000\228\000\228\000\
    \228\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \228\000\228\000\228\000\228\000\228\000\228\000\228\000\228\000\
    \228\000\228\000\228\000\228\000\228\000\228\000\228\000\228\000\
    \228\000\228\000\228\000\228\000\228\000\228\000\228\000\228\000\
    \228\000\228\000\255\255\230\000\255\255\255\255\228\000\255\255\
    \228\000\228\000\228\000\228\000\228\000\228\000\228\000\228\000\
    \228\000\228\000\228\000\228\000\228\000\228\000\228\000\228\000\
    \228\000\228\000\228\000\228\000\228\000\228\000\228\000\228\000\
    \228\000\228\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\230\000\255\255\255\255\255\255\255\255\
    \230\000\255\255\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
    \230\000\230\000\230\000\230\000\225\000\233\000\233\000\233\000\
    \233\000\233\000\233\000\233\000\233\000\233\000\233\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\233\000\233\000\
    \233\000\233\000\233\000\233\000\233\000\233\000\233\000\233\000\
    \233\000\233\000\233\000\233\000\233\000\233\000\233\000\233\000\
    \233\000\233\000\233\000\233\000\233\000\233\000\233\000\233\000\
    \255\255\255\255\255\255\255\255\233\000\255\255\233\000\233\000\
    \233\000\233\000\233\000\233\000\233\000\233\000\233\000\233\000\
    \233\000\233\000\233\000\233\000\233\000\233\000\233\000\233\000\
    \233\000\233\000\233\000\233\000\233\000\233\000\233\000\233\000\
    \054\001\054\001\255\255\255\255\054\001\067\001\067\001\067\001\
    \067\001\067\001\067\001\067\001\067\001\067\001\067\001\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\054\001\
    \255\255\054\001\255\255\255\255\255\255\255\255\067\001\054\001\
    \255\255\255\255\255\255\255\255\054\001\255\255\054\001\054\001\
    \054\001\054\001\054\001\054\001\054\001\054\001\054\001\054\001\
    \054\001\255\255\255\255\054\001\255\255\255\255\255\255\255\255\
    \255\255\230\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \054\001\100\001\255\255\100\001\255\255\054\001\100\001\100\001\
    \100\001\100\001\100\001\100\001\100\001\100\001\100\001\100\001\
    \255\255\255\255\054\001\102\001\102\001\102\001\102\001\102\001\
    \102\001\102\001\102\001\102\001\102\001\054\001\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\054\001\255\255\255\255\
    \102\001\255\255\255\255\054\001\255\255\255\255\103\001\255\255\
    \103\001\255\255\054\001\103\001\103\001\103\001\103\001\103\001\
    \103\001\103\001\103\001\103\001\103\001\104\001\104\001\104\001\
    \104\001\104\001\104\001\104\001\104\001\104\001\104\001\255\255\
    \102\001\105\001\105\001\105\001\105\001\105\001\105\001\105\001\
    \105\001\105\001\105\001\106\001\106\001\106\001\106\001\106\001\
    \106\001\106\001\106\001\106\001\106\001\107\001\107\001\107\001\
    \107\001\107\001\107\001\107\001\107\001\107\001\107\001\255\255\
    \114\001\115\001\115\001\115\001\115\001\115\001\115\001\115\001\
    \115\001\115\001\115\001\255\255\255\255\114\001\255\255\255\255\
    \255\255\117\001\115\001\115\001\115\001\115\001\115\001\115\001\
    \255\255\255\255\255\255\255\255\255\255\255\255\117\001\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\115\001\115\001\115\001\115\001\115\001\115\001\
    \255\255\255\255\114\001\255\255\255\255\255\255\255\255\255\255\
    \114\001\255\255\255\255\255\255\114\001\255\255\255\255\255\255\
    \255\255\255\255\255\255\117\001\114\001\255\255\255\255\054\001\
    \114\001\117\001\114\001\114\001\255\255\117\001\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\117\001\255\255\255\255\
    \255\255\117\001\255\255\117\001\117\001\118\001\118\001\118\001\
    \118\001\118\001\118\001\118\001\118\001\118\001\118\001\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\118\001\118\001\
    \118\001\118\001\118\001\118\001\119\001\119\001\119\001\119\001\
    \119\001\119\001\119\001\119\001\119\001\119\001\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\119\001\119\001\119\001\
    \119\001\119\001\119\001\255\255\255\255\255\255\118\001\118\001\
    \118\001\118\001\118\001\118\001\255\255\255\255\255\255\255\255\
    \255\255\255\255\120\001\120\001\120\001\120\001\120\001\120\001\
    \120\001\120\001\120\001\120\001\255\255\119\001\119\001\119\001\
    \119\001\119\001\119\001\120\001\120\001\120\001\120\001\120\001\
    \120\001\255\255\126\001\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\120\001\120\001\120\001\120\001\120\001\
    \120\001\126\001\126\001\126\001\126\001\126\001\126\001\126\001\
    \126\001\126\001\126\001\126\001\126\001\126\001\126\001\126\001\
    \126\001\126\001\126\001\126\001\126\001\126\001\126\001\126\001\
    \126\001\126\001\126\001\255\255\255\255\255\255\255\255\126\001\
    \255\255\126\001\126\001\126\001\126\001\126\001\126\001\126\001\
    \126\001\126\001\126\001\126\001\126\001\126\001\126\001\126\001\
    \126\001\126\001\126\001\126\001\126\001\126\001\126\001\126\001\
    \126\001\126\001\126\001\129\001\129\001\129\001\129\001\129\001\
    \129\001\129\001\129\001\129\001\129\001\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\129\001\129\001\129\001\129\001\
    \129\001\129\001\129\001\129\001\129\001\129\001\129\001\129\001\
    \129\001\129\001\129\001\129\001\129\001\129\001\129\001\129\001\
    \129\001\129\001\129\001\129\001\129\001\129\001\255\255\255\255\
    \255\255\255\255\129\001\255\255\129\001\129\001\129\001\129\001\
    \129\001\129\001\129\001\129\001\129\001\129\001\129\001\129\001\
    \129\001\129\001\129\001\129\001\129\001\129\001\129\001\129\001\
    \129\001\129\001\129\001\129\001\129\001\129\001\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \126\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255";
  Lexing.lex_base_code = 
   "";
  Lexing.lex_backtrk_code = 
   "";
  Lexing.lex_default_code = 
   "";
  Lexing.lex_trans_code = 
   "";
  Lexing.lex_check_code = 
   "";
  Lexing.lex_code = 
   "";
}

let rec read_json v lexbuf =
    __ocaml_lex_read_json_rec v lexbuf 0
and __ocaml_lex_read_json_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 188 "read.mll"
                ( `Bool true )
# 854 "read.ml"

  | 1 ->
# 189 "read.mll"
                ( `Bool false )
# 859 "read.ml"

  | 2 ->
# 190 "read.mll"
                ( `Null )
# 864 "read.ml"

  | 3 ->
# 191 "read.mll"
                (
                  #ifdef FLOAT
                    `Float nan
                  #elif defined FLOATLIT
                    `Floatlit "NaN"
                  #endif
                )
# 875 "read.ml"

  | 4 ->
# 198 "read.mll"
                (
                  #ifdef FLOAT
                    `Float infinity
                  #elif defined FLOATLIT
                    `Floatlit "Infinity"
                  #endif
                )
# 886 "read.ml"

  | 5 ->
# 205 "read.mll"
                (
                  #ifdef FLOAT
                    `Float neg_infinity
                  #elif defined FLOATLIT
                    `Floatlit "-Infinity"
                  #endif
                )
# 897 "read.ml"

  | 6 ->
# 212 "read.mll"
                (
                  #ifdef STRING
	            Bi_outbuf.clear v.buf;
		    `String (finish_string v lexbuf)
                  #elif defined STRINGLIT
                    `Stringlit (finish_stringlit v lexbuf)
                  #endif
                )
# 909 "read.ml"

  | 7 ->
# 220 "read.mll"
                         ( make_positive_int v lexbuf )
# 914 "read.ml"

  | 8 ->
# 221 "read.mll"
                         ( make_negative_int v lexbuf )
# 919 "read.ml"

  | 9 ->
# 222 "read.mll"
                (
                  #ifdef FLOAT
                    `Float (float_of_string (lexeme lexbuf))
                  #elif defined FLOATLIT
                    `Floatlit (lexeme lexbuf)
                  #endif
                 )
# 930 "read.ml"

  | 10 ->
# 230 "read.mll"
                 ( let acc = ref [] in
		   try
		     read_space v lexbuf;
		     read_object_end lexbuf;
		     let field_name = read_ident v lexbuf in
		     read_space v lexbuf;
		     read_colon v lexbuf;
		     read_space v lexbuf;
		     acc := (field_name, read_json v lexbuf) :: !acc;
		     while true do
		       read_space v lexbuf;
		       read_object_sep v lexbuf;
		       read_space v lexbuf;
		       let field_name = read_ident v lexbuf in
		       read_space v lexbuf;
		       read_colon v lexbuf;
		       read_space v lexbuf;
		       acc := (field_name, read_json v lexbuf) :: !acc;
		     done;
		     assert false
		   with End_of_object ->
		     `Assoc (List.rev !acc)
		 )
# 957 "read.ml"

  | 11 ->
# 254 "read.mll"
                 ( let acc = ref [] in
		   try
		     read_space v lexbuf;
		     read_array_end lexbuf;
		     acc := read_json v lexbuf :: !acc;
		     while true do
		       read_space v lexbuf;
		       read_array_sep v lexbuf;
		       read_space v lexbuf;
		       acc := read_json v lexbuf :: !acc;
		     done;
		     assert false
		   with End_of_array ->
		     `List (List.rev !acc)
		 )
# 976 "read.ml"

  | 12 ->
# 270 "read.mll"
                 (
                   #ifdef TUPLE
                     let acc = ref [] in
		     try
		       read_space v lexbuf;
		       read_tuple_end lexbuf;
		       acc := read_json v lexbuf :: !acc;
		       while true do
			 read_space v lexbuf;
			 read_tuple_sep v lexbuf;
			 read_space v lexbuf;
			 acc := read_json v lexbuf :: !acc;
		       done;
		       assert false
		     with End_of_tuple ->
		       `Tuple (List.rev !acc)
	           #else
		     long_error "Invalid token" v lexbuf
                   #endif
		 )
# 1000 "read.ml"

  | 13 ->
# 291 "read.mll"
                 (
                   #ifdef VARIANT
                     read_space v lexbuf;
                     let cons = read_ident v lexbuf in
		     read_space v lexbuf;
		     `Variant (cons, finish_variant v lexbuf)
                   #else
                     long_error "Invalid token" v lexbuf
                   #endif
		 )
# 1014 "read.ml"

  | 14 ->
# 302 "read.mll"
                 ( read_json v lexbuf )
# 1019 "read.ml"

  | 15 ->
# 303 "read.mll"
                 ( finish_comment v lexbuf; read_json v lexbuf )
# 1024 "read.ml"

  | 16 ->
# 304 "read.mll"
                 ( newline v lexbuf; read_json v lexbuf )
# 1029 "read.ml"

  | 17 ->
# 305 "read.mll"
                 ( read_json v lexbuf )
# 1034 "read.ml"

  | 18 ->
# 306 "read.mll"
                 ( custom_error "Unexpected end of input" v lexbuf )
# 1039 "read.ml"

  | 19 ->
# 307 "read.mll"
                 ( long_error "Invalid token" v lexbuf )
# 1044 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_json_rec v lexbuf __ocaml_lex_state

and finish_string v lexbuf =
    __ocaml_lex_finish_string_rec v lexbuf 58
and __ocaml_lex_finish_string_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 311 "read.mll"
                  ( Bi_outbuf.contents v.buf )
# 1056 "read.ml"

  | 1 ->
# 312 "read.mll"
                  ( finish_escaped_char v lexbuf;
		    finish_string v lexbuf )
# 1062 "read.ml"

  | 2 ->
# 314 "read.mll"
                  ( add_lexeme v.buf lexbuf;
		    finish_string v lexbuf )
# 1068 "read.ml"

  | 3 ->
# 316 "read.mll"
                  ( custom_error "Unexpected end of input" v lexbuf )
# 1073 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_finish_string_rec v lexbuf __ocaml_lex_state

and map_string v f lexbuf =
    __ocaml_lex_map_string_rec v f lexbuf 63
and __ocaml_lex_map_string_rec v f lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 319 "read.mll"
                  ( let b = v.buf in
                    f b.Bi_outbuf.o_s 0 b.Bi_outbuf.o_len )
# 1086 "read.ml"

  | 1 ->
# 321 "read.mll"
                  ( finish_escaped_char v lexbuf;
		    map_string v f lexbuf )
# 1092 "read.ml"

  | 2 ->
# 323 "read.mll"
                  ( add_lexeme v.buf lexbuf;
		    map_string v f lexbuf )
# 1098 "read.ml"

  | 3 ->
# 325 "read.mll"
                  ( custom_error "Unexpected end of input" v lexbuf )
# 1103 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_map_string_rec v f lexbuf __ocaml_lex_state

and finish_escaped_char v lexbuf =
    __ocaml_lex_finish_escaped_char_rec v lexbuf 68
and __ocaml_lex_finish_escaped_char_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
let
# 330 "read.mll"
           c
# 1116 "read.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 330 "read.mll"
             ( Bi_outbuf.add_char v.buf c )
# 1120 "read.ml"

  | 1 ->
# 331 "read.mll"
         ( Bi_outbuf.add_char v.buf '\b' )
# 1125 "read.ml"

  | 2 ->
# 332 "read.mll"
         ( Bi_outbuf.add_char v.buf '\012' )
# 1130 "read.ml"

  | 3 ->
# 333 "read.mll"
         ( Bi_outbuf.add_char v.buf '\n' )
# 1135 "read.ml"

  | 4 ->
# 334 "read.mll"
         ( Bi_outbuf.add_char v.buf '\r' )
# 1140 "read.ml"

  | 5 ->
# 335 "read.mll"
         ( Bi_outbuf.add_char v.buf '\t' )
# 1145 "read.ml"

  | 6 ->
let
# 336 "read.mll"
                a
# 1151 "read.ml"
= Lexing.sub_lexeme_char lexbuf (lexbuf.Lexing.lex_start_pos + 1)
and
# 336 "read.mll"
                           b
# 1156 "read.ml"
= Lexing.sub_lexeme_char lexbuf (lexbuf.Lexing.lex_start_pos + 2)
and
# 336 "read.mll"
                                      c
# 1161 "read.ml"
= Lexing.sub_lexeme_char lexbuf (lexbuf.Lexing.lex_start_pos + 3)
and
# 336 "read.mll"
                                                 d
# 1166 "read.ml"
= Lexing.sub_lexeme_char lexbuf (lexbuf.Lexing.lex_start_pos + 4) in
# 337 "read.mll"
         ( let x =
             (hex a lsl 12) lor (hex b lsl 8) lor (hex c lsl 4) lor hex d
           in
           if x >= 0xD800 && x <= 0xDBFF then
             finish_surrogate_pair v x lexbuf
           else
             utf8_of_code v.buf x
         )
# 1177 "read.ml"

  | 7 ->
# 345 "read.mll"
         ( long_error "Invalid escape sequence" v lexbuf )
# 1182 "read.ml"

  | 8 ->
# 346 "read.mll"
         ( custom_error "Unexpected end of input" v lexbuf )
# 1187 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_finish_escaped_char_rec v lexbuf __ocaml_lex_state

and finish_surrogate_pair v x lexbuf =
    __ocaml_lex_finish_surrogate_pair_rec v x lexbuf 82
and __ocaml_lex_finish_surrogate_pair_rec v x lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
let
# 349 "read.mll"
                  a
# 1200 "read.ml"
= Lexing.sub_lexeme_char lexbuf (lexbuf.Lexing.lex_start_pos + 2)
and
# 349 "read.mll"
                             b
# 1205 "read.ml"
= Lexing.sub_lexeme_char lexbuf (lexbuf.Lexing.lex_start_pos + 3)
and
# 349 "read.mll"
                                        c
# 1210 "read.ml"
= Lexing.sub_lexeme_char lexbuf (lexbuf.Lexing.lex_start_pos + 4)
and
# 349 "read.mll"
                                                   d
# 1215 "read.ml"
= Lexing.sub_lexeme_char lexbuf (lexbuf.Lexing.lex_start_pos + 5) in
# 350 "read.mll"
         ( let y =
             (hex a lsl 12) lor (hex b lsl 8) lor (hex c lsl 4) lor hex d
           in
           if y >= 0xDC00 && y <= 0xDFFF then
             utf8_of_surrogate_pair v.buf x y
           else
             long_error "Invalid low surrogate for code point beyond U+FFFF"
               v lexbuf
         )
# 1227 "read.ml"

  | 1 ->
# 359 "read.mll"
         ( long_error "Missing escape sequence representing low surrogate \
                       for code point beyond U+FFFF" v lexbuf )
# 1233 "read.ml"

  | 2 ->
# 361 "read.mll"
         ( custom_error "Unexpected end of input" v lexbuf )
# 1238 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_finish_surrogate_pair_rec v x lexbuf __ocaml_lex_state

and finish_stringlit v lexbuf =
    __ocaml_lex_finish_stringlit_rec v lexbuf 91
and __ocaml_lex_finish_stringlit_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 366 "read.mll"
         ( let len = lexbuf.lex_curr_pos - lexbuf.lex_start_pos in
	   let s = String.create (len+1) in
	   s.[0] <- '"';
	   String.blit lexbuf.lex_buffer lexbuf.lex_start_pos s 1 len;
	   s
	 )
# 1255 "read.ml"

  | 1 ->
# 372 "read.mll"
         ( long_error "Invalid string literal" v lexbuf )
# 1260 "read.ml"

  | 2 ->
# 373 "read.mll"
         ( custom_error "Unexpected end of input" v lexbuf )
# 1265 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_finish_stringlit_rec v lexbuf __ocaml_lex_state

and finish_variant v lexbuf =
    __ocaml_lex_finish_variant_rec v lexbuf 102
and __ocaml_lex_finish_variant_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 376 "read.mll"
         ( let x = read_json v lexbuf in
	   read_space v lexbuf;
	   read_gt v lexbuf;
	   Some x )
# 1280 "read.ml"

  | 1 ->
# 380 "read.mll"
         ( None )
# 1285 "read.ml"

  | 2 ->
# 381 "read.mll"
         ( long_error "Expected ':' or '>' but found" v lexbuf )
# 1290 "read.ml"

  | 3 ->
# 382 "read.mll"
         ( custom_error "Unexpected end of input" v lexbuf )
# 1295 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_finish_variant_rec v lexbuf __ocaml_lex_state

and read_lt v lexbuf =
    __ocaml_lex_read_lt_rec v lexbuf 107
and __ocaml_lex_read_lt_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 385 "read.mll"
             ( () )
# 1307 "read.ml"

  | 1 ->
# 386 "read.mll"
             ( long_error "Expected '<' but found" v lexbuf )
# 1312 "read.ml"

  | 2 ->
# 387 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 1317 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_lt_rec v lexbuf __ocaml_lex_state

and read_gt v lexbuf =
    __ocaml_lex_read_gt_rec v lexbuf 111
and __ocaml_lex_read_gt_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 390 "read.mll"
         ( () )
# 1329 "read.ml"

  | 1 ->
# 391 "read.mll"
         ( long_error "Expected '>' but found" v lexbuf )
# 1334 "read.ml"

  | 2 ->
# 392 "read.mll"
         ( custom_error "Unexpected end of input" v lexbuf )
# 1339 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_gt_rec v lexbuf __ocaml_lex_state

and read_comma v lexbuf =
    __ocaml_lex_read_comma_rec v lexbuf 115
and __ocaml_lex_read_comma_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 395 "read.mll"
         ( () )
# 1351 "read.ml"

  | 1 ->
# 396 "read.mll"
         ( long_error "Expected ',' but found" v lexbuf )
# 1356 "read.ml"

  | 2 ->
# 397 "read.mll"
         ( custom_error "Unexpected end of input" v lexbuf )
# 1361 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_comma_rec v lexbuf __ocaml_lex_state

and start_any_variant v lexbuf =
    __ocaml_lex_start_any_variant_rec v lexbuf 119
and __ocaml_lex_start_any_variant_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 400 "read.mll"
             ( `Edgy_bracket )
# 1373 "read.ml"

  | 1 ->
# 401 "read.mll"
             ( Bi_outbuf.clear v.buf;
	       `Double_quote )
# 1379 "read.ml"

  | 2 ->
# 403 "read.mll"
             ( `Square_bracket )
# 1384 "read.ml"

  | 3 ->
# 404 "read.mll"
             ( long_error "Expected '<', '\"' or '[' but found" v lexbuf )
# 1389 "read.ml"

  | 4 ->
# 405 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 1394 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_start_any_variant_rec v lexbuf __ocaml_lex_state

and finish_comment v lexbuf =
    __ocaml_lex_finish_comment_rec v lexbuf 125
and __ocaml_lex_finish_comment_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 408 "read.mll"
         ( () )
# 1406 "read.ml"

  | 1 ->
# 409 "read.mll"
         ( long_error "Unterminated comment" v lexbuf )
# 1411 "read.ml"

  | 2 ->
# 410 "read.mll"
         ( newline v lexbuf; finish_comment v lexbuf )
# 1416 "read.ml"

  | 3 ->
# 411 "read.mll"
         ( finish_comment v lexbuf )
# 1421 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_finish_comment_rec v lexbuf __ocaml_lex_state

and read_eof lexbuf =
    __ocaml_lex_read_eof_rec lexbuf 131
and __ocaml_lex_read_eof_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 419 "read.mll"
              ( true )
# 1433 "read.ml"

  | 1 ->
# 420 "read.mll"
              ( false )
# 1438 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_eof_rec lexbuf __ocaml_lex_state

and read_space v lexbuf =
    __ocaml_lex_read_space_rec v lexbuf 133
and __ocaml_lex_read_space_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 423 "read.mll"
                             ( newline v lexbuf; read_space v lexbuf )
# 1450 "read.ml"

  | 1 ->
# 424 "read.mll"
                             ( finish_comment v lexbuf; read_space v lexbuf )
# 1455 "read.ml"

  | 2 ->
# 425 "read.mll"
                             ( newline v lexbuf; read_space v lexbuf )
# 1460 "read.ml"

  | 3 ->
# 426 "read.mll"
                             ( read_space v lexbuf )
# 1465 "read.ml"

  | 4 ->
# 427 "read.mll"
                             ( () )
# 1470 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_space_rec v lexbuf __ocaml_lex_state

and read_null v lexbuf =
    __ocaml_lex_read_null_rec v lexbuf 140
and __ocaml_lex_read_null_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 430 "read.mll"
              ( () )
# 1482 "read.ml"

  | 1 ->
# 431 "read.mll"
              ( long_error "Expected 'null' but found" v lexbuf )
# 1487 "read.ml"

  | 2 ->
# 432 "read.mll"
              ( custom_error "Unexpected end of input" v lexbuf )
# 1492 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_null_rec v lexbuf __ocaml_lex_state

and read_null_if_possible v lexbuf =
    __ocaml_lex_read_null_if_possible_rec v lexbuf 147
and __ocaml_lex_read_null_if_possible_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 435 "read.mll"
              ( true )
# 1504 "read.ml"

  | 1 ->
# 436 "read.mll"
              ( false )
# 1509 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_null_if_possible_rec v lexbuf __ocaml_lex_state

and read_bool v lexbuf =
    __ocaml_lex_read_bool_rec v lexbuf 152
and __ocaml_lex_read_bool_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 439 "read.mll"
              ( true )
# 1521 "read.ml"

  | 1 ->
# 440 "read.mll"
              ( false )
# 1526 "read.ml"

  | 2 ->
# 441 "read.mll"
              ( long_error "Expected 'true' or 'false' but found" v lexbuf )
# 1531 "read.ml"

  | 3 ->
# 442 "read.mll"
              ( custom_error "Unexpected end of input" v lexbuf )
# 1536 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_bool_rec v lexbuf __ocaml_lex_state

and read_int v lexbuf =
    __ocaml_lex_read_int_rec v lexbuf 164
and __ocaml_lex_read_int_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 445 "read.mll"
                         ( try extract_positive_int lexbuf
			   with Int_overflow ->
			     lexer_error "Int overflow" v lexbuf )
# 1550 "read.ml"

  | 1 ->
# 448 "read.mll"
                         ( try extract_negative_int lexbuf
			   with Int_overflow ->
			     lexer_error "Int overflow" v lexbuf )
# 1557 "read.ml"

  | 2 ->
# 451 "read.mll"
                         ( (* Support for double-quoted "ints" *)
                           Bi_outbuf.clear v.buf;
                           let s = finish_string v lexbuf in
                           try
                             (* Any OCaml-compliant int will pass,
                                including hexadecimal and octal notations,
                                and embedded underscores *)
                             int_of_string s
                           with _ ->
                             custom_error
                               "Expected an integer but found a string that \
                                doesn't even represent an integer"
                               v lexbuf
                         )
# 1575 "read.ml"

  | 3 ->
# 465 "read.mll"
                         ( long_error "Expected integer but found" v lexbuf )
# 1580 "read.ml"

  | 4 ->
# 466 "read.mll"
                         ( custom_error "Unexpected end of input" v lexbuf )
# 1585 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_int_rec v lexbuf __ocaml_lex_state

and read_int32 v lexbuf =
    __ocaml_lex_read_int32_rec v lexbuf 173
and __ocaml_lex_read_int32_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 469 "read.mll"
                         ( try Int32.of_string (Lexing.lexeme lexbuf)
			   with _ ->
			     lexer_error "Int32 overflow" v lexbuf )
# 1599 "read.ml"

  | 1 ->
# 472 "read.mll"
                         ( (* Support for double-quoted "ints" *)
                           Bi_outbuf.clear v.buf;
                           let s = finish_string v lexbuf in
                           try
                             (* Any OCaml-compliant int will pass,
                                including hexadecimal and octal notations,
                                and embedded underscores *)
                             Int32.of_string s
                           with _ ->
                             custom_error
                               "Expected an int32 but found a string that \
                                doesn't even represent an integer"
                               v lexbuf
                         )
# 1617 "read.ml"

  | 2 ->
# 486 "read.mll"
                         ( long_error "Expected int32 but found" v lexbuf )
# 1622 "read.ml"

  | 3 ->
# 487 "read.mll"
                         ( custom_error "Unexpected end of input" v lexbuf )
# 1627 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_int32_rec v lexbuf __ocaml_lex_state

and read_int64 v lexbuf =
    __ocaml_lex_read_int64_rec v lexbuf 180
and __ocaml_lex_read_int64_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 490 "read.mll"
                         ( try Int64.of_string (Lexing.lexeme lexbuf)
			   with _ ->
			     lexer_error "Int32 overflow" v lexbuf )
# 1641 "read.ml"

  | 1 ->
# 493 "read.mll"
                         ( (* Support for double-quoted "ints" *)
                           Bi_outbuf.clear v.buf;
                           let s = finish_string v lexbuf in
                           try
                             (* Any OCaml-compliant int will pass,
                                including hexadecimal and octal notations,
                                and embedded underscores *)
                             Int64.of_string s
                           with _ ->
                             custom_error
                               "Expected an int64 but found a string that \
                                doesn't even represent an integer"
                               v lexbuf
                         )
# 1659 "read.ml"

  | 2 ->
# 507 "read.mll"
                         ( long_error "Expected int64 but found" v lexbuf )
# 1664 "read.ml"

  | 3 ->
# 508 "read.mll"
                         ( custom_error "Unexpected end of input" v lexbuf )
# 1669 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_int64_rec v lexbuf __ocaml_lex_state

and read_number v lexbuf =
    __ocaml_lex_read_number_rec v lexbuf 187
and __ocaml_lex_read_number_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 511 "read.mll"
                ( nan )
# 1681 "read.ml"

  | 1 ->
# 512 "read.mll"
                ( infinity )
# 1686 "read.ml"

  | 2 ->
# 513 "read.mll"
                ( neg_infinity )
# 1691 "read.ml"

  | 3 ->
# 514 "read.mll"
                ( float_of_string (lexeme lexbuf) )
# 1696 "read.ml"

  | 4 ->
# 515 "read.mll"
                ( Bi_outbuf.clear v.buf;
	          let s = finish_string v lexbuf in
                  try
                    (* Any OCaml-compliant float will pass,
                       including hexadecimal and octal notations,
                       and embedded underscores. *)
                    float_of_string s
                  with _ ->
                    match s with
                        "NaN" -> nan
                      | "Infinity" -> infinity
                      | "-Infinity" -> neg_infinity
                      | _ ->
                          custom_error
                            "Expected a number but found a string that \
                             doesn't even represent a number"
                            v lexbuf
                )
# 1718 "read.ml"

  | 5 ->
# 533 "read.mll"
                ( long_error "Expected number but found" v lexbuf )
# 1723 "read.ml"

  | 6 ->
# 534 "read.mll"
                ( custom_error "Unexpected end of input" v lexbuf )
# 1728 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_number_rec v lexbuf __ocaml_lex_state

and read_string v lexbuf =
    __ocaml_lex_read_string_rec v lexbuf 221
and __ocaml_lex_read_string_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 537 "read.mll"
             ( Bi_outbuf.clear v.buf;
	       finish_string v lexbuf )
# 1741 "read.ml"

  | 1 ->
# 539 "read.mll"
             ( long_error "Expected '\"' but found" v lexbuf )
# 1746 "read.ml"

  | 2 ->
# 540 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 1751 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_string_rec v lexbuf __ocaml_lex_state

and read_ident v lexbuf =
    __ocaml_lex_read_ident_rec v lexbuf 225
and __ocaml_lex_read_ident_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 543 "read.mll"
             ( Bi_outbuf.clear v.buf;
	       finish_string v lexbuf )
# 1764 "read.ml"

  | 1 ->
let
# 545 "read.mll"
             s
# 1770 "read.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 546 "read.mll"
             ( s )
# 1774 "read.ml"

  | 2 ->
# 547 "read.mll"
             ( long_error "Expected string or identifier but found" v lexbuf )
# 1779 "read.ml"

  | 3 ->
# 548 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 1784 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_ident_rec v lexbuf __ocaml_lex_state

and map_ident v f lexbuf =
    __ocaml_lex_map_ident_rec v f lexbuf 230
and __ocaml_lex_map_ident_rec v f lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 551 "read.mll"
             ( Bi_outbuf.clear v.buf;
	       map_string v f lexbuf )
# 1797 "read.ml"

  | 1 ->
# 554 "read.mll"
             ( map_lexeme f lexbuf )
# 1802 "read.ml"

  | 2 ->
# 555 "read.mll"
             ( long_error "Expected string or identifier but found" v lexbuf )
# 1807 "read.ml"

  | 3 ->
# 556 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 1812 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_map_ident_rec v f lexbuf __ocaml_lex_state

and read_sequence read_cell init_acc v lexbuf =
    __ocaml_lex_read_sequence_rec read_cell init_acc v lexbuf 235
and __ocaml_lex_read_sequence_rec read_cell init_acc v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 559 "read.mll"
             ( let acc = ref init_acc in
	       try
		 read_space v lexbuf;
		 read_array_end lexbuf;
		 acc := read_cell !acc v lexbuf;
		 while true do
		   read_space v lexbuf;
		   read_array_sep v lexbuf;
		   read_space v lexbuf;
		   acc := read_cell !acc v lexbuf;
		 done;
		 assert false
	       with End_of_array ->
		 !acc
	     )
# 1838 "read.ml"

  | 1 ->
# 574 "read.mll"
             ( long_error "Expected '[' but found" v lexbuf )
# 1843 "read.ml"

  | 2 ->
# 575 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 1848 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_sequence_rec read_cell init_acc v lexbuf __ocaml_lex_state

and read_list_rev read_cell v lexbuf =
    __ocaml_lex_read_list_rev_rec read_cell v lexbuf 239
and __ocaml_lex_read_list_rev_rec read_cell v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 578 "read.mll"
             ( let acc = ref [] in
	       try
		 read_space v lexbuf;
		 read_array_end lexbuf;
		 acc := read_cell v lexbuf :: !acc;
		 while true do
		   read_space v lexbuf;
		   read_array_sep v lexbuf;
		   read_space v lexbuf;
		   acc := read_cell v lexbuf :: !acc;
		 done;
		 assert false
	       with End_of_array ->
		 !acc
	     )
# 1874 "read.ml"

  | 1 ->
# 593 "read.mll"
             ( long_error "Expected '[' but found" v lexbuf )
# 1879 "read.ml"

  | 2 ->
# 594 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 1884 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_list_rev_rec read_cell v lexbuf __ocaml_lex_state

and read_array_end lexbuf =
    __ocaml_lex_read_array_end_rec lexbuf 243
and __ocaml_lex_read_array_end_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 597 "read.mll"
             ( raise End_of_array )
# 1896 "read.ml"

  | 1 ->
# 598 "read.mll"
             ( () )
# 1901 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_array_end_rec lexbuf __ocaml_lex_state

and read_array_sep v lexbuf =
    __ocaml_lex_read_array_sep_rec v lexbuf 245
and __ocaml_lex_read_array_sep_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 601 "read.mll"
             ( () )
# 1913 "read.ml"

  | 1 ->
# 602 "read.mll"
             ( raise End_of_array )
# 1918 "read.ml"

  | 2 ->
# 603 "read.mll"
             ( long_error "Expected ',' or ']' but found" v lexbuf )
# 1923 "read.ml"

  | 3 ->
# 604 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 1928 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_array_sep_rec v lexbuf __ocaml_lex_state

and read_tuple read_cell init_acc v lexbuf =
    __ocaml_lex_read_tuple_rec read_cell init_acc v lexbuf 250
and __ocaml_lex_read_tuple_rec read_cell init_acc v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 608 "read.mll"
                 (
                   #ifdef TUPLE
                     let pos = ref 0 in
                     let acc = ref init_acc in
		     try
		       read_space v lexbuf;
		       read_tuple_end lexbuf;
		       acc := read_cell !pos !acc v lexbuf;
		       incr pos;
		       while true do
			 read_space v lexbuf;
			 read_tuple_sep v lexbuf;
			 read_space v lexbuf;
			 acc := read_cell !pos !acc v lexbuf;
			 incr pos;
		       done;
		       assert false
		     with End_of_tuple ->
		       !acc
	           #else
		     long_error "Invalid token" v lexbuf
                   #endif
		 )
# 1962 "read.ml"

  | 1 ->
# 631 "read.mll"
             ( long_error "Expected ')' but found" v lexbuf )
# 1967 "read.ml"

  | 2 ->
# 632 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 1972 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_tuple_rec read_cell init_acc v lexbuf __ocaml_lex_state

and read_tuple_end lexbuf =
    __ocaml_lex_read_tuple_end_rec lexbuf 254
and __ocaml_lex_read_tuple_end_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 635 "read.mll"
             ( raise End_of_tuple )
# 1984 "read.ml"

  | 1 ->
# 636 "read.mll"
             ( () )
# 1989 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_tuple_end_rec lexbuf __ocaml_lex_state

and read_tuple_end2 v std lexbuf =
    __ocaml_lex_read_tuple_end2_rec v std lexbuf 256
and __ocaml_lex_read_tuple_end2_rec v std lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 639 "read.mll"
             ( if std then 
                 long_error "Expected ')' or '' but found" v lexbuf
               else
                 raise End_of_tuple )
# 2004 "read.ml"

  | 1 ->
# 643 "read.mll"
             ( if std then 
                 raise End_of_tuple
               else
                 long_error "Expected ']' or '' but found" v lexbuf )
# 2012 "read.ml"

  | 2 ->
# 647 "read.mll"
             ( () )
# 2017 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_tuple_end2_rec v std lexbuf __ocaml_lex_state

and read_tuple_sep v lexbuf =
    __ocaml_lex_read_tuple_sep_rec v lexbuf 259
and __ocaml_lex_read_tuple_sep_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 650 "read.mll"
             ( () )
# 2029 "read.ml"

  | 1 ->
# 651 "read.mll"
             ( raise End_of_tuple )
# 2034 "read.ml"

  | 2 ->
# 652 "read.mll"
             ( long_error "Expected ',' or ')' but found" v lexbuf )
# 2039 "read.ml"

  | 3 ->
# 653 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 2044 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_tuple_sep_rec v lexbuf __ocaml_lex_state

and read_tuple_sep2 v std lexbuf =
    __ocaml_lex_read_tuple_sep2_rec v std lexbuf 264
and __ocaml_lex_read_tuple_sep2_rec v std lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 656 "read.mll"
             ( () )
# 2056 "read.ml"

  | 1 ->
# 657 "read.mll"
             ( if std then 
                 long_error "Expected ',' or ']' but found" v lexbuf
               else
                 raise End_of_tuple )
# 2064 "read.ml"

  | 2 ->
# 661 "read.mll"
             ( if std then 
                 raise End_of_tuple
               else
                 long_error "Expected ',' or ')' but found" v lexbuf )
# 2072 "read.ml"

  | 3 ->
# 665 "read.mll"
             ( long_error "Expected ',' or ')' but found" v lexbuf )
# 2077 "read.ml"

  | 4 ->
# 666 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 2082 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_tuple_sep2_rec v std lexbuf __ocaml_lex_state

and read_fields read_field init_acc v lexbuf =
    __ocaml_lex_read_fields_rec read_field init_acc v lexbuf 270
and __ocaml_lex_read_fields_rec read_field init_acc v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 669 "read.mll"
             ( let acc = ref init_acc in
	       try
		 read_space v lexbuf;
		 read_object_end lexbuf;
		 let field_name = read_ident v lexbuf in
		 read_space v lexbuf;
		 read_colon v lexbuf;
		 read_space v lexbuf;
		 acc := read_field !acc field_name v lexbuf;
		 while true do
		   read_space v lexbuf;
		   read_object_sep v lexbuf;
		   read_space v lexbuf;
		   let field_name = read_ident v lexbuf in
		   read_space v lexbuf;
		   read_colon v lexbuf;
		   read_space v lexbuf;
		   acc := read_field !acc field_name v lexbuf;
		 done;
		 assert false
	       with End_of_object ->
		 !acc
	     )
# 2116 "read.ml"

  | 1 ->
# 692 "read.mll"
             ( long_error "Expected '{' but found" v lexbuf )
# 2121 "read.ml"

  | 2 ->
# 693 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 2126 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_fields_rec read_field init_acc v lexbuf __ocaml_lex_state

and read_lcurl v lexbuf =
    __ocaml_lex_read_lcurl_rec v lexbuf 274
and __ocaml_lex_read_lcurl_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 696 "read.mll"
             ( () )
# 2138 "read.ml"

  | 1 ->
# 697 "read.mll"
             ( long_error "Expected '{' but found" v lexbuf )
# 2143 "read.ml"

  | 2 ->
# 698 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 2148 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_lcurl_rec v lexbuf __ocaml_lex_state

and read_object_end lexbuf =
    __ocaml_lex_read_object_end_rec lexbuf 278
and __ocaml_lex_read_object_end_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 701 "read.mll"
             ( raise End_of_object )
# 2160 "read.ml"

  | 1 ->
# 702 "read.mll"
             ( () )
# 2165 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_object_end_rec lexbuf __ocaml_lex_state

and read_object_sep v lexbuf =
    __ocaml_lex_read_object_sep_rec v lexbuf 280
and __ocaml_lex_read_object_sep_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 705 "read.mll"
             ( () )
# 2177 "read.ml"

  | 1 ->
# 706 "read.mll"
             ( raise End_of_object )
# 2182 "read.ml"

  | 2 ->
# 707 "read.mll"
             ( long_error "Expected ',' or '}' but found" v lexbuf )
# 2187 "read.ml"

  | 3 ->
# 708 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 2192 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_object_sep_rec v lexbuf __ocaml_lex_state

and read_colon v lexbuf =
    __ocaml_lex_read_colon_rec v lexbuf 285
and __ocaml_lex_read_colon_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 711 "read.mll"
             ( () )
# 2204 "read.ml"

  | 1 ->
# 712 "read.mll"
             ( long_error "Expected ':' but found" v lexbuf )
# 2209 "read.ml"

  | 2 ->
# 713 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 2214 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_colon_rec v lexbuf __ocaml_lex_state

and start_any_tuple v lexbuf =
    __ocaml_lex_start_any_tuple_rec v lexbuf 289
and __ocaml_lex_start_any_tuple_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 716 "read.mll"
             ( false )
# 2226 "read.ml"

  | 1 ->
# 717 "read.mll"
             ( true )
# 2231 "read.ml"

  | 2 ->
# 718 "read.mll"
             ( long_error "Expected '(' or '[' but found" v lexbuf )
# 2236 "read.ml"

  | 3 ->
# 719 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 2241 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_start_any_tuple_rec v lexbuf __ocaml_lex_state

and read_lpar v lexbuf =
    __ocaml_lex_read_lpar_rec v lexbuf 294
and __ocaml_lex_read_lpar_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 722 "read.mll"
             ( () )
# 2253 "read.ml"

  | 1 ->
# 723 "read.mll"
             ( long_error "Expected '(' but found" v lexbuf )
# 2258 "read.ml"

  | 2 ->
# 724 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 2263 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_lpar_rec v lexbuf __ocaml_lex_state

and read_rpar v lexbuf =
    __ocaml_lex_read_rpar_rec v lexbuf 298
and __ocaml_lex_read_rpar_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 727 "read.mll"
             ( () )
# 2275 "read.ml"

  | 1 ->
# 728 "read.mll"
             ( long_error "Expected ')' but found" v lexbuf )
# 2280 "read.ml"

  | 2 ->
# 729 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 2285 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_rpar_rec v lexbuf __ocaml_lex_state

and read_lbr v lexbuf =
    __ocaml_lex_read_lbr_rec v lexbuf 302
and __ocaml_lex_read_lbr_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 732 "read.mll"
             ( () )
# 2297 "read.ml"

  | 1 ->
# 733 "read.mll"
             ( long_error "Expected '[' but found" v lexbuf )
# 2302 "read.ml"

  | 2 ->
# 734 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 2307 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_lbr_rec v lexbuf __ocaml_lex_state

and read_rbr v lexbuf =
    __ocaml_lex_read_rbr_rec v lexbuf 306
and __ocaml_lex_read_rbr_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 737 "read.mll"
             ( () )
# 2319 "read.ml"

  | 1 ->
# 738 "read.mll"
             ( long_error "Expected ']' but found" v lexbuf )
# 2324 "read.ml"

  | 2 ->
# 739 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 2329 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_read_rbr_rec v lexbuf __ocaml_lex_state

and skip_json v lexbuf =
    __ocaml_lex_skip_json_rec v lexbuf 310
and __ocaml_lex_skip_json_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 745 "read.mll"
                ( () )
# 2341 "read.ml"

  | 1 ->
# 746 "read.mll"
                ( () )
# 2346 "read.ml"

  | 2 ->
# 747 "read.mll"
                ( () )
# 2351 "read.ml"

  | 3 ->
# 748 "read.mll"
                ( () )
# 2356 "read.ml"

  | 4 ->
# 749 "read.mll"
                ( () )
# 2361 "read.ml"

  | 5 ->
# 750 "read.mll"
                ( () )
# 2366 "read.ml"

  | 6 ->
# 751 "read.mll"
                ( finish_skip_stringlit v lexbuf )
# 2371 "read.ml"

  | 7 ->
# 752 "read.mll"
                          ( () )
# 2376 "read.ml"

  | 8 ->
# 753 "read.mll"
                ( () )
# 2381 "read.ml"

  | 9 ->
# 755 "read.mll"
                 ( try
		     read_space v lexbuf;
		     read_object_end lexbuf;
		     skip_ident v lexbuf;
		     read_space v lexbuf;
		     read_colon v lexbuf;
		     read_space v lexbuf;
		     skip_json v lexbuf;
		     while true do
		       read_space v lexbuf;
		       read_object_sep v lexbuf;
		       read_space v lexbuf;
		       skip_ident v lexbuf;
		       read_space v lexbuf;
		       read_colon v lexbuf;
		       read_space v lexbuf;
		       skip_json v lexbuf;
		     done;
		     assert false
		   with End_of_object ->
		     ()
		 )
# 2407 "read.ml"

  | 10 ->
# 778 "read.mll"
                 ( try
		     read_space v lexbuf;
		     read_array_end lexbuf;
		     skip_json v lexbuf;
		     while true do
		       read_space v lexbuf;
		       read_array_sep v lexbuf;
		       read_space v lexbuf;
		       skip_json v lexbuf;
		     done;
		     assert false
		   with End_of_array ->
		     ()
		 )
# 2425 "read.ml"

  | 11 ->
# 793 "read.mll"
                 (
                   #ifdef TUPLE
                     try
		       read_space v lexbuf;
		       read_tuple_end lexbuf;
		       skip_json v lexbuf;
		       while true do
			 read_space v lexbuf;
			 read_tuple_sep v lexbuf;
			 read_space v lexbuf;
			 skip_json v lexbuf;
		       done;
		       assert false
		     with End_of_tuple ->
		       ()
	           #else
		     long_error "Invalid token" v lexbuf
                   #endif
		 )
# 2448 "read.ml"

  | 12 ->
# 813 "read.mll"
                 (
                   #ifdef VARIANT
                     read_space v lexbuf;
                     skip_ident v lexbuf;
		     read_space v lexbuf;
		     finish_skip_variant v lexbuf
                   #else
                     long_error "Invalid token" v lexbuf
                   #endif
		 )
# 2462 "read.ml"

  | 13 ->
# 824 "read.mll"
                 ( skip_json v lexbuf )
# 2467 "read.ml"

  | 14 ->
# 825 "read.mll"
                 ( finish_comment v lexbuf; skip_json v lexbuf )
# 2472 "read.ml"

  | 15 ->
# 826 "read.mll"
                 ( newline v lexbuf; skip_json v lexbuf )
# 2477 "read.ml"

  | 16 ->
# 827 "read.mll"
                 ( skip_json v lexbuf )
# 2482 "read.ml"

  | 17 ->
# 828 "read.mll"
                 ( custom_error "Unexpected end of input" v lexbuf )
# 2487 "read.ml"

  | 18 ->
# 829 "read.mll"
                 ( long_error "Invalid token" v lexbuf )
# 2492 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_skip_json_rec v lexbuf __ocaml_lex_state

and finish_skip_stringlit v lexbuf =
    __ocaml_lex_finish_skip_stringlit_rec v lexbuf 366
and __ocaml_lex_finish_skip_stringlit_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 835 "read.mll"
         ( () )
# 2504 "read.ml"

  | 1 ->
# 836 "read.mll"
         ( long_error "Invalid string literal" v lexbuf )
# 2509 "read.ml"

  | 2 ->
# 837 "read.mll"
         ( custom_error "Unexpected end of input" v lexbuf )
# 2514 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_finish_skip_stringlit_rec v lexbuf __ocaml_lex_state

and finish_skip_variant v lexbuf =
    __ocaml_lex_finish_skip_variant_rec v lexbuf 377
and __ocaml_lex_finish_skip_variant_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 840 "read.mll"
         ( skip_json v lexbuf;
	   read_space v lexbuf;
	   read_gt v lexbuf )
# 2528 "read.ml"

  | 1 ->
# 843 "read.mll"
         ( () )
# 2533 "read.ml"

  | 2 ->
# 844 "read.mll"
         ( long_error "Expected ':' or '>' but found" v lexbuf )
# 2538 "read.ml"

  | 3 ->
# 845 "read.mll"
         ( custom_error "Unexpected end of input" v lexbuf )
# 2543 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_finish_skip_variant_rec v lexbuf __ocaml_lex_state

and skip_ident v lexbuf =
    __ocaml_lex_skip_ident_rec v lexbuf 382
and __ocaml_lex_skip_ident_rec v lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 848 "read.mll"
             ( finish_skip_stringlit v lexbuf )
# 2555 "read.ml"

  | 1 ->
# 849 "read.mll"
             ( () )
# 2560 "read.ml"

  | 2 ->
# 850 "read.mll"
             ( long_error "Expected string or identifier but found" v lexbuf )
# 2565 "read.ml"

  | 3 ->
# 851 "read.mll"
             ( custom_error "Unexpected end of input" v lexbuf )
# 2570 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_skip_ident_rec v lexbuf __ocaml_lex_state

and junk lexbuf =
    __ocaml_lex_junk_rec lexbuf 387
and __ocaml_lex_junk_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 854 "read.mll"
             ( Lexing.lexeme lexbuf )
# 2582 "read.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_junk_rec lexbuf __ocaml_lex_state

;;

# 856 "read.mll"
 
  let _ = (read_json : lexer_state -> Lexing.lexbuf -> json)

  let () =
    read_junk := junk

  let read_int8 v lexbuf =
    let n = read_int v lexbuf in
    if n < 0 || n > 255 then
      lexer_error "Int8 overflow" v lexbuf
    else
      char_of_int n

  let read_list read_cell v lexbuf =
    List.rev (read_list_rev read_cell v lexbuf)

  let array_of_rev_list l =
    match l with
	[] -> [| |]
      | x :: tl ->
	  let len = List.length l in
	  let a = Array.make len x in
	  let r = ref tl in
	  for i = len - 2 downto 0 do
	    a.(i) <- List.hd !r;
	    r := List.tl !r
	  done;
	  a

  let read_array read_cell v lexbuf =
    let l = read_list_rev read_cell v lexbuf in
    array_of_rev_list l

  let finish v lexbuf =
    read_space v lexbuf;
    if not (read_eof lexbuf) then
      long_error "Junk after end of JSON value:" v lexbuf

  let init_lexer = init_lexer

  let from_lexbuf v ?(stream = false) lexbuf =
    read_space v lexbuf;

    let x =
      if read_eof lexbuf then
	raise End_of_input
      else
	read_json v lexbuf
    in

    if not stream then
      finish v lexbuf;

    x


  let from_string ?buf ?fname ?lnum s =
    try
      let lexbuf = Lexing.from_string s in
      let v = init_lexer ?buf ?fname ?lnum () in
      from_lexbuf v lexbuf
    with End_of_input ->
      json_error "Blank input data"

  let from_channel ?buf ?fname ?lnum ic =
    try
      let lexbuf = Lexing.from_channel ic in
      let v = init_lexer ?buf ?fname ?lnum () in
      from_lexbuf v lexbuf
    with End_of_input ->
      json_error "Blank input data"

  let from_file ?buf ?fname ?lnum file =
    let ic = open_in file in
    try
      let x = from_channel ?buf ?fname ?lnum ic in
      close_in ic;
      x
    with e ->
      close_in_noerr ic;
      raise e

  let stream_from_lexbuf v ?(fin = fun () -> ()) lexbuf =
    let stream = Some true in
    let f i =
      try Some (from_lexbuf v ?stream lexbuf)
      with
	  End_of_input ->
	    fin ();
	    None
	| e ->
	    (try fin () with _ -> ());
	    raise e
    in
    Stream.from f

  let stream_from_string ?buf ?fname ?lnum s =
    let v = init_lexer ?buf ?fname ?lnum () in
    stream_from_lexbuf v (Lexing.from_string s)

  let stream_from_channel ?buf ?fin ?fname ?lnum ic =
    let lexbuf = Lexing.from_channel ic in
    let v = init_lexer ?buf ?fname ?lnum () in
    stream_from_lexbuf v ?fin lexbuf

  let stream_from_file ?buf ?fname ?lnum file =
    let ic = open_in file in
    let fin () = close_in ic in
    let fname =
      match fname with
	  None -> Some file
	| x -> x
    in
    let lexbuf = Lexing.from_channel ic in
    let v = init_lexer ?buf ?fname ?lnum () in
    stream_from_lexbuf v ~fin lexbuf

  type json_line = [ `Json of json | `Exn of exn ]

  let linestream_from_channel
      ?buf ?(fin = fun () -> ()) ?fname ?lnum:(lnum0 = 1) ic =
    let buf =
      match buf with
	  None -> Some (Bi_outbuf.create 256)
	| Some _ -> buf
    in
    let f i =
      try 
	let line = input_line ic in
	let lnum = lnum0 + i in
	Some (`Json (from_string ?buf ?fname ~lnum line))
      with
	  End_of_file -> fin (); None
	| e -> Some (`Exn e)
    in
    Stream.from f

  let linestream_from_file ?buf ?fname ?lnum file =
    let ic = open_in file in
    let fin () = close_in ic in
    let fname =
      match fname with
	  None -> Some file
	| x -> x
    in
    linestream_from_channel ?buf ~fin ?fname ?lnum ic

  let prettify ?std s =
    pretty_to_string ?std (from_string s)

  let compact ?std s =
    to_string (from_string s)

# 2743 "read.ml"
